@@ -2,7 +2,7 @@
 # ----------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2009 Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2009/04/19, v3.000.020, generateCollectorDaemonSchedulingReports.sh
+# 2009/mm/dd, v3.001.000, generateCollectorDaemonSchedulingReports.sh
 # ----------------------------------------------------------------------------------------------------------
 
 if [ -f ~/.profile ]; then
@@ -13,7 +13,7 @@ if [ -f ~/.bash_profile ]; then
   source ~/.bash_profile
 fi
 
-AMPATH=/opt/asnmtap-3.000.xxx
+AMPATH=/opt/asnmtap
 
 if [ "$ASNMTAP_PATH" ]; then
   AMPATH=$ASNMTAP_PATH
